==> tidypredict_1.0.1.tar.gz: tidypredict/tests/testthat/_snaps/model-glmnet.md <==
# returns the right output

    Code
      rlang::expr_text(tf)
    Output
      [1] "35.3137765116027 + (cyl * -0.871451193824228) + (hp * -0.0101173960249783) + \n    (wt * -2.59443677687505)"

# formulas produces correct predictions

    Code
      tidypredict_test(glmnet::glmnet(mtcars[, -1], mtcars$mpg, family = "gaussian",
      lambda = 1), mtcars[, -1])
    Output
      tidypredict test results
      Difference threshold: 1e-12
      
       All results are within the difference threshold

---

    Code
      tidypredict_test(glmnet::glmnet(mtcars[, -8], mtcars$vs, family = "binomial",
      lambda = 1), mtcars[, -1])
    Output
      tidypredict test results
      Difference threshold: 1e-12
      
       All results are within the difference threshold

---

    Code
      tidypredict_test(glmnet::glmnet(mtcars[, -8], mtcars$vs, family = "poisson",
      lambda = 1), mtcars[, -1])
    Output
      tidypredict test results
      Difference threshold: 1e-12
      
       All results are within the difference threshold

# errors if more than 1 penalty is selected

    Code
      tidypredict_fit(model)
    Condition
      Error in `parse_model()`:
      ! `tidypredict_fit()` requires that there are only 1 penalty selected, 79 were provided.

---

    Code
      tidypredict_fit(model)
    Condition
      Error in `parse_model()`:
      ! `tidypredict_fit()` requires that there are only 1 penalty selected, 2 were provided.

# glmnet are handeld neatly with parsnip

    Code
      rlang::expr_text(tf)
    Output
      [1] "35.3140536966127 + (cyl * -0.871623418095165) + (hp * -0.0101157918502673) + \n    (wt * -2.59426484734253)"

==> tidypredict_1.1.0.tar.gz: tidypredict/tests/testthat/_snaps/model-glmnet.md <==
# returns the right output

    Code
      rlang::expr_text(tf)
    Output
      [1] "35.3137765116027 + (cyl * -0.871451193824228) + (hp * -0.0101173960249783) + \n    (wt * -2.59443677687505)"

# formulas produces correct predictions

    Code
      tidypredict_test(glmnet::glmnet(mtcars[, -1], mtcars$mpg, family = "gaussian",
      lambda = 1), mtcars[, -1])
    Output
      tidypredict test results
      Difference threshold: 1e-12
      
       All results are within the difference threshold

---

    Code
      tidypredict_test(glmnet::glmnet(mtcars[, -8], mtcars$vs, family = "binomial",
      lambda = 1), mtcars[, -1])
    Output
      tidypredict test results
      Difference threshold: 1e-12
      
       All results are within the difference threshold

---

    Code
      tidypredict_test(glmnet::glmnet(mtcars[, -8], mtcars$vs, family = "poisson",
      lambda = 1), mtcars[, -1])
    Output
      tidypredict test results
      Difference threshold: 1e-12
      
       All results are within the difference threshold

# errors if more than 1 penalty is selected

    Code
      tidypredict_fit(model)
    Condition
      Error in `parse_model()`:
      ! `tidypredict_fit()` requires that there are only 1 penalty selected, 79 were provided.

---

    Code
      tidypredict_fit(model)
    Condition
      Error in `parse_model()`:
      ! `tidypredict_fit()` requires that there are only 1 penalty selected, 2 were provided.

# glmnet are handeld neatly with parsnip

    Code
      rlang::expr_text(tf)
    Output
      [1] "35.3140536966127 + (cyl * -0.871623418095165) + (hp * -0.0101157918502673) + \n    (wt * -2.59426484734253)"

# multinomial family errors with helpful message (#198)

    Code
      tidypredict_fit(model)
    Condition
      Error in `tidypredict_fit()`:
      ! Multinomial glmnet models are not supported.
      i Models fit with `family = "multinomial"` have multiple outcome columns which is not supported.

# mgaussian family errors with helpful message (#199)

    Code
      tidypredict_fit(model)
    Condition
      Error in `tidypredict_fit()`:
      ! Multivariate gaussian glmnet models are not supported.
      i Models fit with `family = "mgaussian"` have multiple outcome columns which is not supported.

# .extract_glmnet_multiclass errors on non-multnet model

    Code
      .extract_glmnet_multiclass(model)
    Condition
      Error in `.extract_glmnet_multiclass()`:
      ! `model` must be <multnet>, not an <elnet> object.

# .extract_glmnet_multiclass errors with multiple penalties

    Code
      .extract_glmnet_multiclass(model)
    Condition
      Error in `.extract_glmnet_multiclass()`:
      ! glmnet model has multiple penalty values.
      i Specify a single `penalty` value.
